// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef LIBKSIEVEUI_VERSION_H
#define LIBKSIEVEUI_VERSION_H

#define LIBKSIEVEUI_VERSION_STRING "6.7.0"
#define LIBKSIEVEUI_VERSION_MAJOR 6
#define LIBKSIEVEUI_VERSION_MINOR 7
#define LIBKSIEVEUI_VERSION_PATCH 0
#define LIBKSIEVEUI_VERSION ((6<<16)|(7<<8)|(0))

#endif
