
#ifndef KSIEVECORE_EXPORT_H
#define KSIEVECORE_EXPORT_H

#ifdef KSIEVECORE_STATIC_DEFINE
#  define KSIEVECORE_EXPORT
#  define KSIEVECORE_NO_EXPORT
#else
#  ifndef KSIEVECORE_EXPORT
#    ifdef KPim6KSieveCore_EXPORTS
        /* We are building this library */
#      define KSIEVECORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KSIEVECORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KSIEVECORE_NO_EXPORT
#    define KSIEVECORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KSIEVECORE_DEPRECATED
#  define KSIEVECORE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KSIEVECORE_DEPRECATED_EXPORT
#  define KSIEVECORE_DEPRECATED_EXPORT KSIEVECORE_EXPORT KSIEVECORE_DEPRECATED
#endif

#ifndef KSIEVECORE_DEPRECATED_NO_EXPORT
#  define KSIEVECORE_DEPRECATED_NO_EXPORT KSIEVECORE_NO_EXPORT KSIEVECORE_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KSIEVECORE_NO_DEPRECATED
#    define KSIEVECORE_NO_DEPRECATED
#  endif
#endif

#endif /* KSIEVECORE_EXPORT_H */
